Builder API for constructing Searches.

Structs

Default bobs and singles created automatically by Monument.
Builder API for a call.
Convenient description of a set of courses via Masks.
Builder API for a method.
The unique identifier for a Method.
A set of Methods.
A type of music that Monument should care about.
The unique identifier for a MusicType.
An inclusive range where each side is optionally bounded.
Builder API for constructing searches.

Enums

The different types of BaseCalls that can be created.
How the calls in a given composition should be displayed.
Where in a lead can a method finish.
The length range of a Search.
The different styles of spliced that can be generated.

Constants

Default weight given to bobs.
Default weight given to user-specified Calls.
Default weight given to singles.