pub struct Call { /* private fields */ }
Builder API for a call.

Implementations

Starts building a call which replaces the lead end with a given PlaceNotation and is displayed with the given symbol.

If set, this call will use a different symbol for debugging as displaying. This is currently only used for bobs (which display as ‘’ but debug as ‘-’).

If debug_symbol isn’t called, this will be the same as the ‘display’ symbol.

If passed Some(_), the behaviour is the same as Call::debug_symbol; if None is passed, the behaviour is reverted to the default (using the same symbol for debug and display).

Forces the use of a given set of calling positions. The supplied Vec contains one String for every place, in order, including leading. For example, default calling positions for near bobs in Major would be vec!["L", "I", "B", "F", "V", "M", "W", "H"].

If Some(_) is passed, behaves the same as Call::calling_positions. If None is passed, the calling_positions are reverted to the default.

Sets the label marking where this call can be placed. If unset, all calls are applied to the lead end.

Makes this call go to a different label than it goes from.

Sets the weight which is added every time this call is used.