Convenient description of a set of courses via Masks.
Fields
masks: Vec<Mask>List of Masks, of which courses should match at least one.
any_stroke: boolIf true, the Masks will be expanded so that the mask matches on both strokes. For
example, "*5678" might expand to ["*5678", "*6587"].
any_bells: boolIf true, every Bell in every Mask will be added/subtracted from to get every
combination. For example, "*3456" would expand to
["*1234", "*2345", "*3456", "*4567", "*5678"].