pub enum Error {
Show 15 variants
MethodNotFound {
title: String,
suggestions: Vec<(String, usize)>,
},
MethodPnParse {
name: String,
place_notation_string: String,
error: PnBlockParseError,
},
CustomCourseMaskParse {
method_title: String,
mask_str: String,
error: ParseError,
},
DifferentStartEndRowInMultipart,
UndefinedLabel {
call_name: String,
label: String,
},
NoMethods,
DuplicateShorthand {
shorthand: String,
title1: String,
title2: String,
},
WrongCallingPositionsLength {
call_name: String,
calling_position_len: usize,
stage: Stage,
},
DuplicateCall {
symbol: String,
label: String,
pn1: PlaceNot,
pn2: PlaceNot,
},
SizeLimit(usize),
InconsistentStroke,
UnachievableLength {
requested_range: RangeInclusive<TotalLength>,
next_shorter_len: Option<usize>,
next_longer_len: Option<usize>,
},
UnachievableMethodCount {
method_name: String,
requested_range: OptionalRangeInclusive,
next_shorter_len: Option<usize>,
next_longer_len: Option<usize>,
},
TooMuchMethodCount {
min_total_method_count: usize,
max_length: usize,
},
TooLittleMethodCount {
max_total_method_count: usize,
min_length: usize,
},
}Expand description
The different ways that Monument can fail.
Variants
MethodNotFound
The given title couldn’t be found in the Central Council library. Each suggestions is
paired with its ‘edit distance’ (i.e. a metric of how different it is from the requested
title)
MethodPnParse
Some method’s place notation failed to parse
CustomCourseMaskParse
Some course mask couldn’t be parsed.
DifferentStartEndRowInMultipart
Different start/end rows were specified in a multi-part
UndefinedLabel
Some Call refers to a label that doesn’t exist
NoMethods
No methods were defined
DuplicateShorthand
Two Methods use the same shorthand
WrongCallingPositionsLength
DuplicateCall
Two Calls have the same lead location and name
SizeLimit(usize)
The given maximum graph size limit was reached
InconsistentStroke
The same chunk of ringing could start at two different strokes, and some
MusicType relies on the strokes always being the same
UnachievableLength
The requested length range isn’t achievable
Fields
requested_range: RangeInclusive<TotalLength>UnachievableMethodCount
Some method range isn’t achievable
Fields
requested_range: OptionalRangeInclusiveTooMuchMethodCount
The total of the minimum method counts is longer than the composition
TooLittleMethodCount