pub enum QueryUpdate {
    Comp(Comp),
    Progress(Progress),
    TruncatingQueue,
    Aborting,
}
Instances of this are emitted by the search as it’s running

Variants

Comp(Comp)

A new composition has been found

Progress(Progress)

A thread is sending a status update

TruncatingQueue

The queue of prefixes has got too large and is being shortened

Aborting

The search is being aborted