Creation and manipulation of composition graphs. This implements routines for creating and optimising such graphs, in preparation for performing tree search.

Modules

A plugin-able system of passes made over the composition Graph, in order to modify or optimise the graph.

Structs

A Chunk in a chunk Graph. This is an indivisible chunk of ringing which cannot be split up by calls or splices.

A ‘prototype’ chunk graph that is (relatively) inefficient to traverse but easy to modify. This is usually used to build and optimise the chunk graph before being converted into an efficient graph representation for use in tree search.

A link between two Chunks in a Graph

Unique identifier for a Link within a Graph

A HashMap containing a set of Links, all addressed by unique LinkIds

Enums

The different ways that graph building can fail