pub struct Composition { /* private fields */ }
A Composition generated by Monument.

Implementations

The number of Rows in this composition.

Generate a human-friendly String summarising the calling of this composition. For example, this composition would have a call_string of D[B]BL[W]N[M]SE[sH]NCYW[sH].

The Row reached at the end of the first part. If this is a 1-part, then this will be rounds.

Return a Block containing the Rows in this composition. Each Row is annotated with a (method index, index within a lead) pair. For example, splicing a lead of Bastow into Cambridge Major would create a Block which starts like:

Block {
    12345678: (<ID of Bastow>, 0),
    21436587: (<ID of Bastow>, 1),
    21345678: (<ID of Bastow>, 2),
    12436587: (<ID of Bastow>, 3),
    14263857: (<ID of Cambridge>, 0),
    41628375: (<ID of Cambridge>, 1),
    14682735: (<ID of Cambridge>, 2),
    41867253: (<ID of Cambridge>, 3),
    48162735: (<ID of Cambridge>, 4),
       ...
}

The total score generated by this composition from all the different weights (music, calls, changes of method, handbell coursing, etc.).

The average score generated by each Row in this composition. This is equal to self.total_score() / self.length() as f32.

Score generated by just the MusicTypes (not including calls, changes of methods, etc.).

A slice containing the number of Rows generated for each Method used in the Search. These are stored in the same order as the Methods.

The number of instances of each MusicType in the Search.

Return an Iterator over the number of Rows in each transition between non_duffer_courses.

Returns the total number of Rows of duffer courses (i.e. those not in SearchBuilder::non_duffer_courses) present in this composition.