pub struct Progress {
    pub iter_count: usize,
    pub queue_len: usize,
    pub avg_length: f32,
    pub max_length: u32,
}

Fields

iter_count: usize

How many chunks have been expanded so far

queue_len: usize

The current length of the A* queue

avg_length: f32

The average length of a composition in the queue

max_length: u32

The length of the longest composition in the queue

Implementations

The Progress made by a search which hasn’t started yet