Module utils

Module utils 

Structs

PerPartLength
A length in one part of the composition. This and TotalLength allow the compiler to disallow mixing up the different definitions of ‘length’.
TotalLength
The combined length across all parts. This and PerPartLength allow the compiler to disallow mixing up the different definitions of ‘length’.

Enums

Boundary