Builder API for constructing Searches.
Structs
Default bobs and singles created automatically by Monument.
Builder API for a call.
Builder API for a method.
A type of music that Monument should care about.
The unique identifier for a
MusicType.An inclusive range where each side is optionally bounded.
Builder API for constructing searches.
Enums
The different types of
BaseCalls that can be created.How the calls in a given composition should be displayed.
Where in a lead can a method finish.
The different styles of spliced that can be generated.
Constants
Default weight given to bobs.
Default weight given to user-specified
Calls.Default weight given to singles.