pub struct Call { /* private fields */ }Expand description
Builder API for a call.
Implementations
sourceimpl Call
impl Call
sourcepub fn debug_symbol(self, symbol: impl Into<String>) -> Self
pub fn debug_symbol(self, symbol: impl Into<String>) -> Self
If set, this call will use a different symbol for debugging as displaying. This is currently only used for bobs (which display as ‘’ but debug as ‘-’).
If debug_symbol isn’t called, this will be the same as the ‘display’ symbol.
sourcepub fn maybe_debug_symbol<T: Into<String>>(self, symbol: Option<T>) -> Self
pub fn maybe_debug_symbol<T: Into<String>>(self, symbol: Option<T>) -> Self
If passed Some(_), the behaviour is the same as Call::debug_symbol; if None
is passed, the behaviour is reverted to the default (using the same symbol for debug and
display).
sourcepub fn calling_positions(self, positions: Vec<String>) -> Self
pub fn calling_positions(self, positions: Vec<String>) -> Self
sourcepub fn maybe_calling_positions(self, positions: Option<Vec<String>>) -> Self
pub fn maybe_calling_positions(self, positions: Option<Vec<String>>) -> Self
If Some(_) is passed, behaves the same as Call::calling_positions. If None
is passed, the calling_positions are reverted to the default.
sourcepub fn label(self, label: impl Into<String>) -> Self
pub fn label(self, label: impl Into<String>) -> Self
Sets the label marking where this call can be placed. If unset, all calls are applied to the lead end.