Creation and manipulation of composition graphs. This implements routines for creating and optimising such graphs, in preparation for performing tree search.
Modules
Structs
A Chunk in a chunk Graph. This is an indivisible chunk of ringing which cannot be split up
by calls or splices.
A ‘prototype’ chunk graph that is (relatively) inefficient to traverse but easy to modify. This is usually used to build and optimise the chunk graph before being converted into an efficient graph representation for use in tree search.
Enums
The different ways that graph building can fail