pub struct Config {
pub num_threads: Option<usize>,
pub optimisation_passes: Vec<Mutex<Pass>>,
pub graph_size_limit: usize,
pub split_by_start_chunk: bool,
pub queue_limit: usize,
pub mem_forget_search_data: bool,
}Expand description
Configuration parameters for Monument which don’t change which compositions are emitted.
Fields
num_threads: Option<usize>Number of threads used to generate compositions. If None, this uses the number of
physical CPU cores (i.e. ignoring hyper-threading).
optimisation_passes: Vec<Mutex<Pass>>graph_size_limit: usizeThe maximum graph size, in nodes. If a search would produce a graph bigger than this, it is aborted.
split_by_start_chunk: boolqueue_limit: usizemem_forget_search_data: boolIf true, the data structures used by searches will be leaked using std::mem::forget.
This massively improves the termination speed (because all individual allocations don’t
need to be freed), but only makes sense for the CLI, where Monument will do exactly one
search run before terminating (thus returning the memory to the OS anyway).